/* Read an image in PGM format from stdin.
   Compute the edginess and output it to stdout, in PGM format.

   For the article
   "Singularity Detection in Images Using Dual Local Autocovariance"
   by  Wojciech Czaja and Mladen Victor Wickerhauser.

   Programmer: M.V.Wickerhauser <victor@math.wustl.edu>
   Date: 22 July 2001

 */

#include <stdio.h>
#include "edginess.h"

int
main(void)
{
  int n,m;
  Grid image, edges, bump, subg;
  real emat[2][2], evs[2];

  image = readPGM(stdin);
  edges = likeGrid (image);
  bump = gaussian(3);
  subg = likeGrid (bump);
  for ( m = image->r0  ;  m <= image->r1  ;  m++ )
    for ( n = image->c0  ;  n <= image->c1  ;  n++ ) {
      smooth ( subg, image, m,n, bump );
      momenta ( emat, subg );
      eigenvalues ( evs, emat );
      insert ( edges, m,n, edginess(evs) );
    }
  normalize ( edges );
  writePGM ( stdout, edges);
  freeGrid(edges);
  freeGrid(subg);
  freeGrid (bump);
  freeGrid(image);

  return 0;
}
