/* Declare functions used to compute edginess.

   For the article
   "Singularity Detection in Images Using Dual Local Autocovariance"
   by  Wojciech Czaja and Mladen Victor Wickerhauser.

   Programmer: M.V.Wickerhauser <victor@math.wustl.edu>
   Date: 24 July 2001

 */

#ifndef EDGINESS_H_INCLUDED
# define EDGINESS_H_INCLUDED

#include <stdio.h>

typedef float real;

struct Grid {
  real **samples;		/* indexed `samples[r][c]' */
  int rows;			/* number of rows = 1+r1-r0 */
  int cols;			/* number of columns = 1+c1-c0 */
  int r0;			/* least valid `r' index */
  int r1;			/* greatest valid `r' index */
  int c0;			/* least valid `c' index */
  int c1;			/* greatest valid `c' index */
};
typedef	struct Grid	*Grid;

Grid	newGrid		( int r0, int r1, int c0, int c1, const real *in );
Grid	likeGrid	( Grid in );
Grid	copyGrid	( Grid out, Grid in );
void	freeGrid	( Grid in );
real	sample		( Grid g, int row, int col );
void	insert		( Grid g, int row, int col, real x );
void	sharp		( Grid out, Grid in, int i0, int j0 );
void	smooth		( Grid out, Grid in, int i0, int j0, Grid bump );
Grid	gaussian	( int e );
void	eigenvalues	( real lambda[2], real symmat[2][2] );
void	momenta		( real out[2][2], Grid in );
real	edginess	( const real evs[2] );
real	normalize	( Grid g );
Grid	readPGM		( FILE *pgmfile );
void	writePGM	( FILE *pgmfile, Grid in );
void	printGrid	( Grid in, const char *message );
void	print2x2	( real in[2][2], const char *message );

#endif /* EDGINESS_H_INCLUDED */
